/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
/**
 * Configuration file for Cypress e2e tests.
 */
const { defineConfig } = require("cypress");
const fs = require("fs");
const csv = require("csv-parser");

module.exports = defineConfig({
  e2e: {
    //this is to disable auto-run when saving changes
    watchForFileChanges: false,
    /**
     * Sets up task events for Cypress.
     * @param {Function} on - Cypress event listener.
     * @param {Object} config - Cypress configuration object.
     */
    setupNodeEvents(on, config) {
      on("task", {
        /**
         * Custom task to read elements from a CSV file.
         * @param {string} filePath - Path to the CSV file.
         * @returns {Promise<Array<Object>>} - Promise resolving to an array of elements.
         */
        getElements({ filePath }) {
          return new Promise((resolve, reject) => {
            const elements = [];
            fs.createReadStream(filePath)
              .pipe(csv({ separator: ";" }))
              .on("data", (row) => {
                elements.push(row);
              })
              .on("end", () => {
                resolve(elements);
              })
              .on("error", (error) => {
                reject(error);
              });
          });
        }
      });
    }
  }
});
