/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import * as elements from "./elements.cy.js"; //importiert alles aus elements.cy.js
import { check } from "./common";
import { checkSpecificElement } from "./common";
import { checkFirstElementThatFulfillsConditionOfMissingElement } from "./common";
import { login } from "./loginLogout.cy.js";
import { logout } from "./loginLogout.cy.js";

describe("template spec local", () => {
  it("checks the styles of an element", function () {
    cy.visit("https://bup-ozg-ci-frontend.pidev.mgm-tp.com/");

    //preconditon: at least one new and one answered message is available on overview page

    cy.log("**login**");
    login(cy);

    //checks heading and subheading
    cy.log("**check inbox heading**");
    check(cy, "inboxHeading", elements.INBOXHEADING);
    cy.log("**check inbox subheading**");
    check(cy, "inboxSubheading", elements.INBOXSUBHEADING);

    //checks the overall frame around all messages
    cy.log("**check overview frame**");
    check(cy, "overviewFrame", elements.OVERVIEWLIST);

    //checks the frame of the first list entry
    cy.log("**check frame of first list entry**");
    checkSpecificElement(cy, "overviewMessageFrame", elements.getFirstMessage(cy));

    //checks the badge of first list entry
    cy.log("**check badge of first list entry**");
    checkSpecificElement(cy, "overviewNewBadge", elements.getFirstNewBadge(cy));

    //checks the heading of the first list entry
    cy.log("**check heading of first list entry**");
    checkSpecificElement(cy, "overviewMessageHeading", elements.getFirstMessageHeading(cy));

    //checks the subheading of first list entry
    cy.log("**check subheading of first list entry**");
    checkSpecificElement(cy, "overviewMessageSubheading", elements.getFirstMessageSubheading(cy));

    //checks the open button of first list entry (new message)
    cy.log("**check open button of first list entry (new message)**");
    checkSpecificElement(cy, "buttonOpenNewMessage", elements.getFirstOpenButtonNew(cy));

    //checks the open button of first list entry which has no "NEU" badge (answered message)
    cy.log("**check open button of answered message**");
    checkFirstElementThatFulfillsConditionOfMissingElement(cy, elements.OVERVIEWLIST, "NEU", (el) => {
      const oeffnenButtonOfThisRow = el.contains("Öffnen");
      checkSpecificElement(cy, "buttonOpenAnsweredMessage", oeffnenButtonOfThisRow);
    });

    //checks the text "Beantwortet am ..." of first list entry which has no "NEU" badge
    cy.log('**check "Beantwortet am" of answered message**');
    checkFirstElementThatFulfillsConditionOfMissingElement(cy, elements.OVERVIEWLIST, "NEU", (el) => {
      const beantwortetOfThisRow = el.contains("Beantwortet");
      checkSpecificElement(cy, "overviewMessageAnswered", beantwortetOfThisRow);
    });

    cy.log("**logout**");
    logout(cy);
  });
});
