/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
/**
 * Mapping of attribute types to assertion methods.
 * @type {Object.<string, string>}
 */
const attributeTypeMapping = {
  role: "have.prop",
  //text: 'have.text'
  text: "contain.text"
};

/**
 * This function checks the CSS properties of an HTMLElement against the configuration for that element
 * @param {object} cy - The cypress object
 * @param {string} elementName - The name of the element as specified in the CSV
 * @param {string} selector - The CSS selector for the element
 */
export function check(cy, elementName, selector) {
  cy.task("getElements", { filePath: "elementSpec.csv" }).then((elements) => {
    // Find the element config
    const elementConfig = elements.find((el) => el.elementName === elementName);

    if (elementConfig) {
      for (const property in elementConfig) {
        if (property !== "elementName" && elementConfig[property] !== "-") {
          if (property === "text") {
            cy.get(selector).should(attributeTypeMapping[property], elementConfig[property]);
          } else {
            cy.get(selector).should(attributeTypeMapping[property] ?? "have.css", property, elementConfig[property]);
          }
        }
      }
    } else {
      throw new Error(`No configuration found for element: ${elementName} ${JSON.stringify(elements)}`);
    }
  });
}

//copied function above and changed
/**
 * This function checks the CSS properties of an HTMLElement against the configuration for that element
 * @param {object} cy - The cypress object
 * @param {string} elementName - The name of the element as specified in the CSV
 * @param {any} htmlElement - The htmlElement that should be checked
 */
export function checkSpecificElement(cy, elementName, htmlElement) {
  cy.task("getElements", { filePath: "elementSpec.csv" }).then((elements) => {
    // Find the element config
    const elementConfig = elements.find((el) => el.elementName === elementName);

    if (elementConfig) {
      for (const property in elementConfig) {
        if (property !== "elementName" && elementConfig[property] !== "-") {
          if (property === "text") {
            htmlElement.should(attributeTypeMapping[property], elementConfig[property]);
          } else {
            htmlElement.should(attributeTypeMapping[property] ?? "have.css", property, elementConfig[property]);
          }
        }
      }
    } else {
      throw new Error(`No configuration found for element: ${elementName} ${JSON.stringify(elements)}`);
    }
  });
}

/**
 * Check the first element in a list that does not contain a specific keyword in its HTML using a provided executor function.
 *
 * @param {Cypress.cy} cy - The Cypress instance.
 * @param {string} listSelector - The CSS selector for the list of elements.
 * @param {string} checkForMissingKeyWord - The keyword to exclude from the search.
 * @param {function} executorFunc - The function to execute on the first element found that doesn't contain the keyword.
 */
export function checkFirstElementThatFulfillsConditionOfMissingElement(
  cy,
  listSelector,
  checkForMissingKeyWord,
  executorFunc
) {
  let el = null;

  cy.get(listSelector)
    .find("li")
    .each(($el) => {
      if ($el.html().indexOf(checkForMissingKeyWord) === -1 && el === null) {
        el = $el;
        executorFunc(cy.wrap($el));
      }
    });
}

// import * as methods from "./methods.js"
// TODO: add testdata
export const usernameBayern = "PLACEHOLDER"; 
export const passwordBayern = "PLACEHOLDER";
export const usernameAlfa = "dorothea";
export const passwordAlfa = "Y9nk43yrQ_zzIPpfFU-I";

export function loginBayern(usernameBayern, passwordBayern) {
  //it('logs in with credentials', () => {
  cy.visit("https://infra-pre-id.bayernportal.de/de");
  cy.contains("Anmelden").click();
  cy.get('[data-test-id="CqLQW"] > .flex-col > .grow').click();
  cy.get('[datatestid="jjTlN"] > .rounded-sm > :nth-child(1) > .relative.w-full > .self-stretch > .w-full').type(
    usernameBayern
  );
  cy.get(".mt-5 > .rounded-sm > :nth-child(1) > .relative.w-full > .self-stretch > .w-full").type(passwordBayern);
  cy.get(".mt-10 > .mt-5 > .transition > .justify-between").click();
  cy.get(
    '[data-test-id="x34XT_0_row"] > .content-width-wide > :nth-child(1) > .mt-2 > .col-start-2 > .text-skin-accent'
  ).click();
  //cy.get('LINK_FROM_MESSAGE_BODY').click();
}

export function loginAlfa(usernameAlfa, passwordAlfa) {
  cy.visit("https://stadt-utopia.test.by.ozg-cloud.de/alle/neu"); //goes directly to NEU overview
  cy.get("#username").type(usernameAlfa);
  cy.get("#password").type(passwordAlfa);
  cy.contains("Anmelden").click();
}

export function answerApplicant(inputSubject, inputBody) {
  //answers 4 applications in
  //loginAlfa(usernameAlfa, passwordAlfa); //written in TC bc blocks auto-re-run
  //cy.get('.selected > .mdc-button > .mdc-button__label').click(); //written in TC bc blocks auto-re-run
  //cy.get(':nth-child(1) > .list-item').click(); //gets first entry of list
  //cy.contains(applicationNumber).click(); //written in TC bc blocks auto-re-run
  cy.get('[text="Nachricht"]').click();
  cy.get(
    "goofy-client-text-editor.ng-pristine > .mat-mdc-form-field > .mat-mdc-text-field-wrapper > .mat-mdc-form-field-flex > .mat-mdc-form-field-infix"
  ).type(inputSubject);
  cy.get(
    ".message-editor > .mat-mdc-form-field > .mat-mdc-text-field-wrapper > .mat-mdc-form-field-flex > .mat-mdc-form-field-infix"
  ).type(inputBody);
  //to be added: file upload
  cy.contains("Senden").click();
  cy.get(":nth-child(1) > goofy-client-outgoing-mail.ng-star-inserted > a > .subject").should(
    "have.text",
    inputSubject
  );
  cy.get(":nth-child(1) > goofy-client-outgoing-mail.ng-star-inserted > a > .message").should("have.text", inputBody);
}

export function throwOutApplication(applicationNumber) {
  //loginAlfa(usernameAlfa, passwordAlfa)
  cy.get(applicationNumber);
  cy.get("goofy-client-vorgang-detail-formular-buttons > goofy-client-verwerfen-button").click();
}

export function acceptApplication(applicationNumber) {
  //loginAlfa(usernameAlfa, passwordAlfa)
  cy.get(applicationNumber);
  cy.get("goofy-client-vorgang-detail-formular-buttons > goofy-client-annehmen-button").click();
}
