/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { AttachmentItem } from "../components/Data Display/AttachmentList/AttachmentList";

export type TrustLevel = "LOW" | "SUBSTANTIAL" | "HIGH";

interface BaseMessage {
  id: string;
  postfachId: string;
  nachrichtEventId: string;
}

export interface Message extends BaseMessage {
  message: string;
  attachments: AttachmentItem[];
}

interface Nachricht extends Message {
  title: string;
  vorgangId: string;
  sendAt: number;
  answeredAt?: number;
  accessible: boolean;
  trustLevel: TrustLevel;
}

export interface Antwort extends Message {
  rueckfrageId: string;
}

interface NachrichtHeader extends BaseMessage {
  title: string;
  vorgangId: string;
  sendAt: number;
  answeredAt?: number;
  accessible: boolean;
  trustLevel: TrustLevel;
}

interface BaseRueckfrage {
  id?: string;
  title: string;
  accessible: boolean;
  trustLevel: TrustLevel;
}

export interface Rueckfrage extends BaseRueckfrage {
  nachricht: Nachricht;
  antworten: Antwort[];
}

interface RueckfrageLink {
  rel: string;
  href: string;
}

export interface RueckfrageHeader extends BaseRueckfrage {
  nachrichtHeader: NachrichtHeader;
  status: string;
  links: RueckfrageLink[];
}

export interface CommandReference {
  id: string;
  nachrichtEventId: string;
}

export interface Command extends CommandReference {
  status: string;
  createdAt: number;
  finishedAt?: number;
}

export interface User {
  firstname: string;
  lastname: string;
  exp: number;
  refreshcode: string;
  postkorbhandle: string;
  trustlevel: string;
}
