/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

import { fireEvent, render, screen } from "@testing-library/react";
import React from "react";
import { Button } from "./Button";
import { FaArrowLeft } from "react-icons/fa";

describe("Button tests:", () => {
  let onClick: () => void;
  beforeEach(() => {
    onClick = jest.fn();
  });
  test("Button shows passed text", () => {
    render(<Button onClick={onClick}>Btn</Button>);
    const button = screen.getByTestId("button");
    expect(button).toHaveTextContent("Btn");
  });
  test("Click on button => action is triggered", () => {
    render(<Button onClick={onClick}>Btn</Button>);
    fireEvent.click(screen.getByTestId("button"));
    expect(onClick).toBeCalledTimes(1);
  });
  test("Click on disabled button => no action is triggered", () => {
    render(
      <Button disabled onClick={onClick}>
        Btn
      </Button>
    );
    fireEvent.click(screen.getByTestId("button"));
    expect(onClick).toBeCalledTimes(0);
  });
  test("Icon title is used", async () => {
    render(
      <Button leftSideIcon={<FaArrowLeft title="left arrow" aria-label="left arrow" />} onClick={onClick}>
        Btn
      </Button>
    );

    const iconTitle = screen.getByTitle("left arrow");
    expect(iconTitle).toBeInTheDocument();
  });
  test("Spinner is used", async () => {
    render(
      <Button showSpinner onClick={onClick}>
        Btn
      </Button>
    );

    const spinner = document.querySelector(".spinner");
    expect(spinner).toBeInTheDocument();
  });
});
