/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { fireEvent, render, screen } from "@testing-library/react";
import React from "react";
import { IconButton } from "./IconButton";
import { FaArrowLeft } from "react-icons/fa";
import { GrFormUpload } from "react-icons/gr";

describe("Icon button tests:", () => {
  let onClick: () => void;
  beforeEach(() => {
    onClick = jest.fn();
  });
  test("Click on button => action is triggered", () => {
    render(
      <IconButton icon={<FaArrowLeft title="Left Arrow Icon" aria-label="Left Arrow Icon" />} onClick={onClick} />
    );
    fireEvent.click(screen.getByTestId("icon-button"));
    expect(onClick).toBeCalledTimes(1);
  });
  test("Press enter on button => action is triggered", () => {
    render(
      <IconButton icon={<FaArrowLeft title="Left Arrow Icon" aria-label="Left Arrow Icon" />} onClick={onClick} />
    );
    fireEvent.keyDown(screen.getByTestId("icon-button"), { key: "Enter", code: 13, charCode: 13 });
    expect(onClick).toBeCalledTimes(1);
  });
  test("Click on disabled button => no action is triggered", () => {
    render(
      <IconButton
        disabled
        icon={<FaArrowLeft title="Left Arrow Icon" aria-label="Left Arrow Icon" />}
        onClick={onClick}
      />
    );
    fireEvent.click(screen.getByTestId("icon-button"));
    expect(onClick).toBeCalledTimes(0);
  });
  test("Left arrow icon button has text content from aria label", () => {
    render(
      <IconButton icon={<FaArrowLeft title="Left Arrow Icon" aria-label="Left Arrow Icon" />} onClick={onClick} />
    );
    const button = screen.getByTestId("icon-button");
    expect(button).toHaveTextContent("Left Arrow Icon");
  });
  test("Upload icon button has text content from aria label", () => {
    render(
      <IconButton icon={<GrFormUpload title="Form Upload Icon" aria-label="Form Upload Icon" />} onClick={onClick} />
    );
    const button = screen.getByTestId("icon-button");
    expect(button).toHaveTextContent("Form Upload Icon");
  });
});
