/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { render, screen } from "@testing-library/react";
import React from "react";
import { MessageBody } from "./MessageBody";

describe("Message body tests", () => {
  test("displays text without attachments", () => {
    render(
      <MessageBody
        nachrichtEventId="1"
        nachrichtId="2"
        message="Message of clerk"
        attachments={[]}
        ariaLabel="message body"
        closeIconLabel="close"
      />
    );
    expect(screen.getByTestId("message-body-text")).toHaveTextContent("Message of clerk");
  });
  test("message with line breaks", () => {
    render(
      <MessageBody
        nachrichtEventId="1"
        nachrichtId="2"
        message={`Message with\nline breaks`}
        attachments={[]}
        ariaLabel="message body"
        closeIconLabel="close"
      />
    );
    expect(screen.getByTestId("message-body-text").innerHTML).toBe(
      "<span>Message with<br></span><span>line breaks</span>"
    );
  });
  test("displays message with attachments", () => {
    render(
      <MessageBody
        nachrichtEventId="1"
        nachrichtId="2"
        message="Message of clerk with attachments"
        attachments={[
          { id: "1", fileName: "file1.pdf", fileSize: 512000, contentType: "application/pdf" },
          {
            id: "2",
            fileName: "file2.xlsx",
            fileSize: 819200,
            contentType: "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
          }
        ]}
        ariaLabel="message body"
        closeIconLabel="close"
      />
    );
    expect(screen.getAllByTestId("message-body-text").at(0)).toHaveTextContent("Message of clerk with attachments");
    expect(screen.getAllByTestId("file-name").at(0)).toHaveTextContent("file1.pdf");
    expect(screen.getAllByTestId("text-content").at(0)).toHaveTextContent("500 KB");
    expect(screen.getAllByTestId("file-name").at(1)).toHaveTextContent("file2.xlsx");
    expect(screen.getAllByTestId("text-content").at(1)).toHaveTextContent("800 KB");
  });
  test("cypress index selector", () => {
    render(
      <MessageBody
        nachrichtEventId="1"
        nachrichtId="2"
        index={2}
        message={"message"}
        attachments={[]}
        ariaLabel="message body"
        closeIconLabel="close"
      />
    );
    expect(screen.getByTestId("message-body-text").getAttribute("data-cy")).toBe("message-body-2-content");
  });
});
