/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { render, screen } from "@testing-library/react";
import React from "react";
import { MessageTitle } from "./MessageTitle";

describe("Message title tests", () => {
  test("displays text", () => {
    render(
      <MessageTitle
        title="the title"
        subtitle="the subtitle"
        badgeLabel="neu"
        leftArrowIconLabel="left arrow"
        onReturnClick={jest.fn}
        unread
      />
    );
    expect(screen.getAllByTestId("heading").at(0)).toHaveTextContent("the title");
    expect(screen.getAllByTestId("heading").at(1)).toHaveTextContent("the subtitle");
  });
  test("displays no badge", () => {
    render(
      <MessageTitle
        title="the title"
        subtitle="the subtitle"
        badgeLabel="neu"
        leftArrowIconLabel="left arrow"
        onReturnClick={jest.fn}
      />
    );
    expect(screen.queryByTestId("badge")).not.toBeInTheDocument();
  });
  test("displays badge", () => {
    render(
      <MessageTitle
        title="the title"
        subtitle="the subtitle"
        badgeLabel="neu"
        leftArrowIconLabel="left arrow"
        onReturnClick={jest.fn}
        unread
      />
    );
    expect(screen.queryByTestId("badge")).toBeInTheDocument();
    expect(screen.queryByTestId("badge")).toHaveTextContent("NEU");
  });
  test("back button is disabled", () => {
    const onClick = jest.fn();
    render(
      <MessageTitle
        title="the title"
        subtitle="the subtitle"
        badgeLabel="neu"
        leftArrowIconLabel="left arrow"
        onReturnClick={onClick}
        disableReturnButton={true}
      />
    );
    expect(screen.getByRole("button")).toHaveAttribute("aria-disabled", "true");
    expect(onClick).toBeCalledTimes(0);
  });
});
