/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import React from "react";
import styled from "styled-components";
import { Title } from "../Title/Title";
import { IconButton } from "../../Buttons/IconButton/IconButton";
import { Badge } from "../../Data Display/Badge/Badge";
import { FaArrowLeft } from "react-icons/fa";

const cyIdsPrefix = "message-title-";

interface MessageTitleProps {
  /** The message title. */
  title: string;
  /** The message subtitle. */
  subtitle: string;
  /** The label of the badge. */
  badgeLabel: string;
  /** The accessibility label for the left arrow icon. */
  leftArrowIconLabel: string;
  /** If the meassage is unread. */
  unread?: boolean;
  /** Function to handle the return button icon click. */
  onReturnClick(): void;
  /** Disables the return button. */
  disableReturnButton?: boolean;
}

/**
 * A component to display a message title.
 */
export function MessageTitle(props: MessageTitleProps) {
  return (
    <FlexDiv>
      <IconButton
        disabled={props.disableReturnButton}
        data-cy={`${cyIdsPrefix}back-button`}
        onClick={props.onReturnClick}
        icon={<FaArrowLeft title={props.leftArrowIconLabel} aria-label={props.leftArrowIconLabel} />}
      />
      {props.unread && (
        <Badge data-cy={`${cyIdsPrefix}badge`} role="status" aria-live="assertive" data-testid="badge">
          {props.badgeLabel.toLocaleUpperCase()}
        </Badge>
      )}
      <Title title={props.title} subtitle={props.subtitle} headingLevel={1} />
    </FlexDiv>
  );
}

const FlexDiv = styled.div`
  align-items: center;
  display: flex;
  gap: 10px;
`;
