/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

import { render, screen } from "@testing-library/react";
import React from "react";
import { OverviewListItem } from "./OverviewListItem";
import { Provider } from "react-redux";
import { store } from "../../../../../store";

describe("Overview List Item tests", () => {
  test("title and subtitle are there", () => {
    render(
      <Provider store={store}>
        <OverviewListItem
          title="the title"
          subtitle="the subtitle"
          actionButtonLabel="open"
          trustLevel={"LOW"}
          onClickHandler={() => {}}
          onKeyDownHandler={() => {}}
          showTooltip
          unread
          disabled
        />
      </Provider>
    );
    expect(screen.getAllByTestId("heading").at(0)).toHaveTextContent("the title");
    expect(screen.getAllByTestId("heading").at(1)).toHaveTextContent("the subtitle");
  });

  test("answered at text is there", () => {
    render(
      <Provider store={store}>
        <OverviewListItem
          title="the title"
          subtitle="the subtitle"
          answeredAt="answered"
          actionButtonLabel="open"
          trustLevel={"LOW"}
          onClickHandler={() => {}}
          onKeyDownHandler={() => {}}
          showTooltip={true}
          unread={true}
          disabled={true}
        />
      </Provider>
    );
    expect(screen.getByText("answered")).toBeInTheDocument();
  });

  test("tooltip is there for disabled message with HIGH trustlevel", () => {
    render(
      <Provider store={store}>
        <OverviewListItem
          title="the title"
          subtitle="the subtitle"
          answeredAt="answered"
          actionButtonLabel="open"
          trustLevel={"HIGH"}
          disabled
          onClickHandler={() => {}}
          onKeyDownHandler={() => {}}
          showTooltip={true}
          unread
        />
      </Provider>
    );
    const tooltip: HTMLElement = screen.getByTestId(`overview-rueckfrage-tooltip`) as HTMLElement;
    expect(tooltip).toBeInTheDocument();
  });
});
