/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

import React, { ReactElement } from "react";
import { Title } from "../../../Title/Title";
import { MdLock } from "react-icons/md";
import { useTranslateFunction } from "../../../../../hooks/useTranslate";
import { TrustLevel } from "../../../../../api/types";
import * as S from "./OverviewListItemStyles";
import { Button } from "../../../../Buttons/Button/Button";
import OverviewListItemTooltip from "./OverviewListItemTooltip/OverviewListItemTooltip";

export interface OverviewListItemProps {
  title: string;
  subtitle: string;
  actionButtonLabel: string;
  answeredAt?: string;
  id?: string;
  disabled: boolean;
  trustLevel: TrustLevel;
  unread: boolean;
  onClickHandler: () => void;
  onKeyDownHandler: (e: React.KeyboardEvent) => void;
  showTooltip: boolean;
}

export function OverviewListItem(props: OverviewListItemProps): ReactElement {
  const translate = useTranslateFunction();
  const cyIdsPrefix: string = `overview-rueckfrage-${props.id !== undefined ? props.id + "-" : ""}`;

  let srStatusText: string;
  if (props.disabled) {
    srStatusText = translate(`overviewPage.listItem.status.${props.unread ? "unreadAndDisabled" : "disabled"}`);
  } else {
    srStatusText = translate("overviewPage.listItem.status.unread");
  }

  const buttonLabel: string = props.unread
    ? translate("overviewPage.listItem.button.unread")
    : translate("overviewPage.listItem.button.read");

  return (
    <S.Row>
      <p className={"sr-only"}>{srStatusText}</p>
      <Title
        data-cy={`${cyIdsPrefix}title`}
        title={props.title}
        subtitle={props.subtitle}
        headingLevel={2}
        disabled={props.disabled}
      />
      {props.disabled && props.trustLevel !== "LOW" && (
        <OverviewListItemTooltip showTooltip={props.showTooltip} trustLevel={props.trustLevel} />
      )}
      <S.RightColumn>
        {props.answeredAt && (
          <S.AnsweredAtBox>
            <S.StyledText key="answered-at" data-cy={`${cyIdsPrefix}answered-at`} variant="info">
              {props.answeredAt}
            </S.StyledText>
          </S.AnsweredAtBox>
        )}
        <S.ButtonStylingWrapper disabled={props.disabled} unread={props.unread}>
          <Button
            tabIndex={props.disabled ? -1 : 0}
            role={"link"}
            aria-label={`${
              props.disabled ? translate("overviewPage.listItem.lockedIconAriaLabel") : ""
            } ${buttonLabel}`}
          >
            {props.disabled && <MdLock aria-label={translate("overviewPage.listItem.lockedIconAriaLabel")} />}
            {buttonLabel}
          </Button>
        </S.ButtonStylingWrapper>
      </S.RightColumn>
    </S.Row>
  );
}
