/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import React from "react";
import styled from "styled-components";
import { Heading } from "../../Data Display/Heading/Heading";
import { MdLock } from "react-icons/md";

const cyIdsPrefix = "title-";

interface TitleProps extends React.HTMLAttributes<HTMLDivElement> {
  /** The title. */
  title: string;
  /** The subtitle. */
  subtitle: string;
  /** The title's heading level */
  headingLevel?: 1 | 2 | 3 | 4 | 5 | 6;
  disabled?: boolean;
}

/**
 * A component to display a title with a subtitle.
 */
export function Title({ title, subtitle, headingLevel, disabled, ...props }: TitleProps) {
  return (
    <div {...props}>
      <Heading headingLevel={headingLevel} data-cy={`${cyIdsPrefix}heading`}>
        {disabled && (
          <HeadingIcon>
            <MdLock />
          </HeadingIcon>
        )}
        {title}
      </Heading>
      <Subtitle data-cy={`${cyIdsPrefix}subtitle`} data-testid="heading">
        {subtitle}
      </Subtitle>
    </div>
  );
}

const Subtitle = styled.div`
  margin-top: 4px;
  font-size: 1rem;
`;

const HeadingIcon = styled.div`
  display: inline;
  svg {
    margin: 0 5px -2px 0;
  }
`;
