/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

import React from "react";
import styled from "styled-components";
import { Link } from "../../Data Display/Link/Link";

const cyIdsPrefix = "application-footer";

export interface ApplicationFooterProps {
  privacyPolicyLabel: string;
  imprintLabel: string;
  ozgCloudIconAltText: string;
}

/**
 * The footer of the application.
 */
export function ApplicationFooter(props: ApplicationFooterProps) {
  const ozgCloudLogo = require("../../../assets/ozg_cloud_logo.png") as string;
  return (
    <FooterContainer data-cy={cyIdsPrefix}>
      <FooterNavContainer>
        <Link data-cy={`${cyIdsPrefix}-privacy-policy-link`} url="/privacy-policy">
          {props.privacyPolicyLabel}
        </Link>
        <Link data-cy={`${cyIdsPrefix}-imprint-link`} url="/imprint">
          {props.imprintLabel}
        </Link>
      </FooterNavContainer>
      <LogoContainer>
        <img data-cy={`${cyIdsPrefix}-ozg-cloud-logo`} src={ozgCloudLogo} alt={props.ozgCloudIconAltText} />
      </LogoContainer>
    </FooterContainer>
  );
}

const FooterContainer = styled.footer`
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 36px 10px;
`;

const FooterNavContainer = styled.div`
  flex-grow: 1;

  display: flex;
  justify-content: flex-start;
  flex-wrap: wrap;
  gap: 0.5rem 1rem;
`;

const LogoContainer = styled.div`
  flex-shrink: 0;
`;
