/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

import React from "react";
import { Container } from "../Container/Container";
import { ApplicationFooter } from "../Application Footer/ApplicationFooter";
import { ApplicationHeader } from "../Application Header/ApplicationHeader";
import { MainContent } from "../Main Content/MainContent";
import { User } from "../../../api/types";

export interface ApplicationFrameProps extends React.PropsWithChildren {
  user: User;
  privacyPolicyLabel: string;
  imprintLabel: string;
  pageHeaderAriaLabel: string;
  logoAltText: string;
  userIconAltText: string;
  bayernIdIconAltText: string;
  ozgCloudIconAltText: string;
}

export function ApplicationFrame(props: ApplicationFrameProps) {
  return (
    <Container>
      <ApplicationHeader
        userName={props.user.lastname ?? ""} // keep the name empty if the data is missing
        pageHeaderAriaLabel={props.pageHeaderAriaLabel}
        logoAltText={props.logoAltText}
        userIconAltText={props.userIconAltText}
        bayernIdIconAltText={props.bayernIdIconAltText}
      />
      <MainContent>{props.children}</MainContent>
      <ApplicationFooter
        ozgCloudIconAltText={props.ozgCloudIconAltText}
        privacyPolicyLabel={props.privacyPolicyLabel}
        imprintLabel={props.imprintLabel}
      />
    </Container>
  );
}
