/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import React from "react";
import { ApplicationHeader } from "./ApplicationHeader";
import { render, screen } from "@testing-library/react";

const mockUsedNavigate = jest.fn();
jest.mock("react-router-dom", () => ({
  ...jest.requireActual("react-router-dom"),
  useNavigate: () => mockUsedNavigate
}));

describe("Application Header tests", () => {
  test("displays Application Header", () => {
    render(
      <ApplicationHeader
        userName="Schmidt"
        pageHeaderAriaLabel="Header label"
        logoAltText="logo alt text"
        userIconAltText="user icon alt text"
        bayernIdIconAltText="bayernid alt text"
      />
    );

    expect(screen.getByTestId("user-name")).toHaveTextContent("Schmidt");
    expect(screen.getByTestId("bayernid-icon")).toBeInTheDocument();
  });

  test("displays mobile Application Header", () => {
    Object.defineProperty(window, "innerWidth", {
      writable: true,
      configurable: true,
      value: 400
    });
    render(
      <ApplicationHeader
        userName="Schmidt"
        pageHeaderAriaLabel="Header label"
        logoAltText="logo alt text"
        userIconAltText="user icon alt text"
        bayernIdIconAltText="bayernid alt text"
      />
    );

    expect(screen.queryByTestId("bayernid-icon")).not.toBeInTheDocument();
  });
});
