/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

import React from "react";
import { DropdownMenu, DropdownMenuHeading, DropdownMenuItem } from "./DropdownMenu";
import { fireEvent, render, screen } from "@testing-library/react";
import { FaArrowLeft } from "react-icons/fa";

describe("Dropdown menu tests", () => {
  test("Menu elements are rendered", () => {
    const onClick = jest.fn();
    render(
      <DropdownMenu
        listItems={[
          <DropdownMenuHeading>Heading</DropdownMenuHeading>,
          <DropdownMenuItem handleClick={onClick} icon={<FaArrowLeft />} text="Item" />
        ]}
      />
    );
    expect(screen.getByTestId("menu-heading")).toHaveTextContent("Heading");
    expect(screen.getByTestId("menu-item")).toHaveTextContent("Item");
  });
  test("Click on dropdown menu item works", () => {
    const onClick = jest.fn();
    render(
      <DropdownMenu listItems={[<DropdownMenuItem handleClick={onClick} icon={<FaArrowLeft />} text="Item" />]} />
    );

    fireEvent.click(screen.getByTestId("menu-item"));
    expect(onClick).toBeCalledTimes(1);
  });
  test("Enter on dropdown menu item works", () => {
    const onClick = jest.fn();
    render(
      <DropdownMenu listItems={[<DropdownMenuItem handleClick={onClick} icon={<FaArrowLeft />} text="Item" />]} />
    );

    fireEvent.keyDown(screen.getByTestId("menu-item"), { key: "Enter", code: 13, charCode: 13 });
    expect(onClick).toBeCalledTimes(1);
  });
});
