/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import React from "react";
import styled from "styled-components";
import { Link } from "../../Data Display/Link/Link";
import { Text } from "../../Data Display/Text/Text";
import { COLORS } from "../../constants";
import { Heading } from "../../Data Display/Heading/Heading";

const cyIdsPrefix = "error-page-";

interface ErrorPageProps {
  errorType: "notFound" | "generic";
  headline?: string;
  message: string;
  goBackTo: string;
  linkText: string;
  notFoundIconAltText: string;
  errorIconAltText: string;
}

/**
 * A page to display an error.
 */
export function ErrorPage(props: ErrorPageProps) {
  const errorLogo = require("../../../assets/error.svg") as string;
  const errorIcon = (
    <img
      width={64}
      height={64}
      data-cy={`${cyIdsPrefix}error-logo`}
      src={errorLogo}
      alt={props.errorIconAltText}
      data-testid="error-page-icon"
    />
  );
  const notFoundLogo = require("../../../assets/not_found.svg") as string;
  const notFoundIcon = (
    <img
      width={96}
      height={96}
      data-cy={`${cyIdsPrefix}not-found-logo`}
      src={notFoundLogo}
      alt={props.notFoundIconAltText}
      data-testid="error-page-icon"
    />
  );

  return (
    <StyledPage>
      {props.headline ? <ErrorHeading data-cy={`${cyIdsPrefix}heading`}>{props.headline}</ErrorHeading> : undefined}
      {props.errorType === "notFound" ? notFoundIcon : errorIcon}
      <Message variant="info" data-cy={`${cyIdsPrefix}message`}>
        {props.message}
        <br />
        {props.goBackTo}{" "}
        <StyledLink data-cy={`${cyIdsPrefix}overview-link`} url="/">
          {props.linkText}
        </StyledLink>
        {"."}
      </Message>
    </StyledPage>
  );
}

const ErrorHeading = styled(Heading)`
  font-weight: 600;
`;

const StyledPage = styled.div`
  display: flex;
  padding: 96px 0;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  gap: 16px;
  align-self: stretch;
`;

const Message = styled(Text)`
  text-align: center;
  font-weight: 500;
  font-size: 1rem;
  line-height: 1.5rem;
`;

const StyledLink = styled(Link)`
  text-decoration-line: underline;
  color: ${COLORS.LIGHT_GREY};
  font-size: 1rem;
`;
