/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import React, { useEffect, useState } from "react";
import { flexCenteredPage } from "../../commonStyles";
import styled from "styled-components";

interface LoadingPageProps {
  loadingMessage: string;
}

/**
 * A loading page component.<br />
 * **TODO: the component should be complete when the specification is there.**
 */
export function LoadingPage(props: LoadingPageProps) {
  const [dots, setDots] = useState<string[]>([]);
  useEffect(() => {
    setTimeout(() => {
      if (dots.length < 3) {
        setDots([...dots, "."]);
      } else {
        setDots([]);
      }
    }, 500);
  });
  return (
    <StyledPage>
      {props.loadingMessage}
      {dots.join("")}
    </StyledPage>
  );
}

const StyledPage = styled.div`
  font-size: 2rem;
  font-weight: 700;
  ${flexCenteredPage};
`;
