/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import React from "react";
import styled, { css } from "styled-components";

interface HeadingProps extends React.HTMLAttributes<HTMLDivElement> {
  /** Heading level to improve accessibility */
  headingLevel?: 1 | 2 | 3 | 4 | 5 | 6;
}

/**
 * A simple heading component.
 */
export function Heading({ children, headingLevel, ...props }: HeadingProps) {
  const HeadingComponent = getHeadingComponent(headingLevel ?? 1);
  return (
    <HeadingComponent role="heading" aria-level={headingLevel} {...props} data-testid="heading">
      {children}
    </HeadingComponent>
  );
}

const StyledBaseHeading = css`
  font-size: 1.25rem;
  font-weight: 700;
  margin-block: 0;
  margin-inline: 0;
`;

// there are currently no different heading levels specified by design so this is likely temporary

const StyledH1 = styled.h1`
  ${StyledBaseHeading}
`;

const StyledH2 = styled.h2`
  ${StyledBaseHeading}
`;

const StyledH3 = styled.h3`
  ${StyledBaseHeading};
  font-size: 1.125rem;
`;

const StyledH4 = styled.h4`
  ${StyledBaseHeading};
  font-size: 1rem;
`;

const StyledH5 = styled.h5`
  ${StyledBaseHeading};
  font-size: 1rem;
`;

const StyledH6 = styled.h6`
  ${StyledBaseHeading};
  font-size: 1rem;
`;

function getHeadingComponent(headingLevel: 1 | 2 | 3 | 4 | 5 | 6) {
  switch (headingLevel) {
    case 1:
      return StyledH1;
    case 2:
      return StyledH2;
    case 3:
      return StyledH3;
    case 4:
      return StyledH4;
    case 5:
      return StyledH5;
    default:
      return StyledH6;
  }
}
