/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

import React from "react";
import styled from "styled-components";
import { COLORS, tabletMaxWidth } from "../../constants";

interface ListProps extends React.HTMLAttributes<HTMLUListElement> {}

interface ListItemProps extends React.HTMLAttributes<HTMLLIElement> {
  $unread?: boolean;
  $disabled?: boolean;
  $roundedBorderTop?: boolean;
  $roundedBorderBottom?: boolean;
}

/**
 * A wrapper for lists and list items. The contents of the list items can be arbitrary elements.
 */
export function List({ children, ...props }: ListProps) {
  return <ListWrapper {...props}>{children}</ListWrapper>;
}

export function ListItem({ children, ...props }: ListItemProps) {
  return (
    <ListItemWrapper data-testid="list-item" {...props}>
      {children}
    </ListItemWrapper>
  );
}

const ListWrapper = styled.ul`
  border: 1px solid ${COLORS.LAVENDER_MIST};
  border-radius: 0.75rem;
  list-style-type: none;
  margin-block: 0;
  margin-inline: 0;
  padding-inline: 0;
`;

const ListItemWrapper = styled.li<ListItemProps>`
  position: relative;
  padding: 32px;
  border-top-left-radius: ${(props) => props.$roundedBorderTop && "0.75rem"};
  border-top-right-radius: ${(props) => props.$roundedBorderTop && "0.75rem"};
  border-bottom-left-radius: ${(props) => props.$roundedBorderBottom && "0.75rem"};
  border-bottom-right-radius: ${(props) => props.$roundedBorderBottom && "0.75rem"};
  border-left: ${(props) => {
    if (props.$unread) {
      return props.$disabled ? `12px solid ${COLORS.DISABLED_UNREAD_GREY}` : `12px solid ${COLORS.INTERACTION}`;
    }

    return "";
  }} !important;
  background-color: ${(props) => props.$disabled && "rgb(148, 163, 184,0.1)"};
  color: ${(props) => props.$disabled && `${COLORS.DISABLED_DARK}`};
  cursor: ${(props) => !props.$disabled && "pointer"};

  &:not(:last-child) {
    border-bottom: 1px solid ${COLORS.LAVENDER_MIST};
  }

  &:hover {
    border: ${(props) => !props.$disabled && `2px solid ${COLORS.INTERACTION}`};
  }

  &:focus {
    border: 2px dotted ${COLORS.DISABLED_UNREAD_GREY};
    outline: none;
  }

  @media (max-width: ${tabletMaxWidth}px) {
    padding: 24px;
  }
`;
