/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import React from "react";
import styled from "styled-components";
import { COLORS } from "../../constants";

type Variant = "info" | "error";

interface TextProps extends React.HTMLAttributes<HTMLDivElement> {
  /** Can be info or error. */
  variant: Variant;
  /** Inherited test id for testing purposes */
  dataTestId?: string;
}

/**
 * A simple text component
 */
export function Text({ variant, children, dataTestId, ...props }: TextProps) {
  return (
    <StyledText
      {...props}
      $variant={variant}
      data-testid={dataTestId ?? "text-content"}
      aria-labelledby={children?.toString()}
    >
      {children}
    </StyledText>
  );
}

const StyledText = styled.div<{ $variant: Variant }>`
  color: ${(props) => (props.$variant === "info" ? COLORS.SLATE : COLORS.CARMINE_PINK)};
  overflow-wrap: anywhere;
`;
