/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import React from "react";
import styled from "styled-components";
import { COLORS } from "../../constants";
import { transitionTimingStyles } from "../../commonStyles";

interface TextAreaProps extends React.HTMLAttributes<HTMLTextAreaElement> {
  placeholder?: string;
  value: string;
  onChangeValue(value: string): void;
}

export function TextArea({ placeholder, value, onChangeValue, ...props }: TextAreaProps) {
  return (
    <StyledTextArea
      {...props}
      role="textbox"
      data-testid="textarea"
      value={value}
      onChange={(e) => onChangeValue(e.currentTarget.value)}
      placeholder={placeholder}
    />
  );
}

const StyledTextArea = styled.textarea`
  border: 1px solid ${COLORS.DIVIDER_GREY};
  border-radius: 12px;
  padding: 24px;
  font-size: 1rem;
  max-width: 523px;
  height: 302px;
  resize: none;
  transition-property: outline-offset;
  ${transitionTimingStyles};

  &::placeholder {
    color: ${COLORS.LIGHT_GREY};
  }

  &:focus-visible {
    outline-color: ${COLORS.LIGHT_GREY};
    outline-offset: 2px;
  }
`;
