/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { RootState } from "../../store";
import { changeLocale, localeReducer, LocaleState, selectLocale } from "./localeSlice";

describe("locale reducer", () => {
  const initialLocaleState: LocaleState = {
    locale: "de-DE"
  };
  const initialState: RootState = {
    locale: initialLocaleState,
    rueckfragen: { rueckfrageHeaderStatus: "idle", selectedRueckfrageStatus: "idle", rueckfrageHeaders: [] }
  };
  it("should handle initial state", () => {
    expect(localeReducer(undefined, { type: "unknown" })).toEqual({
      locale: "de-DE"
    });
  });

  it("should handle locale change", () => {
    const actual = localeReducer(initialLocaleState, changeLocale("en-EN"));
    expect(actual.locale).toEqual("en-EN");
  });

  it("should select the locale from state", () => {
    expect(selectLocale(initialState)).toBe("de-DE");
  });
});
