/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { localise } from "./localiser";
import { Locales } from "./types";

describe("localisation", () => {
  const mockLocales: Locales = {
    de: {
      test: { test: "Test", testWithReplaces: "Test {replace1} {replace2}" }
    },
    en: {
      test: { test: "EN", testWithReplaces: "EN {replace1} {replace2}" }
    }
  };
  it("get test key with locale de", () => {
    expect(localise("test.test", mockLocales, "de")).toEqual("Test");
  });
  it("get test key with locale en", () => {
    expect(localise("test.test", mockLocales, "en")).toEqual("EN");
  });
  it("get test key with non-existing locale", () => {
    expect(() => localise("test.test", mockLocales, "fr")).toThrowError("invalid locale");
  });
  it("get test key with replacements", () => {
    expect(localise("test.testWithReplaces", mockLocales, "de", { replace1: "repl", replace2: "test" })).toEqual(
      "Test repl test"
    );
  });
  it("get test key with partial replacements", () => {
    expect(localise("test.testWithReplaces", mockLocales, "de", { replace1: "repl" })).toEqual("Test repl {replace2}");
  });
  it("get test key with too many replacements", () => {
    expect(
      localise("test.testWithReplaces", mockLocales, "de", {
        replace1: "repl",
        replace2: "test",
        replace3: "unnecessary"
      })
    ).toEqual("Test repl test");
  });
  it("get key when undefined", () => {
    expect(localise("undefinedKey", mockLocales, "de", {})).toEqual("undefinedKey");
  });
  it("get key when too long", () => {
    expect(localise("test.test.test", mockLocales, "de")).toEqual("test.test.test");
  });
});
