/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

import React from "react";
import ReactDOM from "react-dom";
import { createRoot } from "react-dom/client";
import { Provider } from "react-redux";
import { store } from "./store";
import { createBrowserRouter, RouterProvider } from "react-router-dom";
import { getRouterConfig } from "./routes/router-config";

const container = document.getElementById("root")!;
const root = createRoot(container);

if (process.env.NODE_ENV !== "production") {
  // axe-core is a plugin that displays accessibility warnings during runtime
  // in the developer tools console
  const axe = require("@axe-core/react");
  axe(React, ReactDOM, 1000);
}

// StrictMode makes Components render twice in development for error checking
root.render(
  <React.StrictMode>
    <Provider store={store}>
      <RouterProvider router={createBrowserRouter(getRouterConfig())} />
    </Provider>
  </React.StrictMode>
);
