/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { formatTimestampToDateAndTime, formatTimestampToDate } from "./date";

describe("Date functions", () => {
  describe("formatTimestamp():", () => {
    test("formats a timestamp in the correct format", () => {
      const dateFormatRegex = /^\d{2}\.\d{2}.\d{4} \d{2}:\d{2}$/;
      expect(formatTimestampToDateAndTime(1698678887603)).toMatch(dateFormatRegex);
    });
    test("formats the linux epoch (contains padding zeros) in the correct format", () => {
      const dateFormatRegex = /^\d{2}\.\d{2}.\d{4} \d{2}:\d{2}$/;
      expect(formatTimestampToDateAndTime(0)).toMatch(dateFormatRegex);
    });
    test("formats the timestamp as just a date if the respective config is set", () => {
      const dateFormatRegex = /^\d{2}\.\d{2}.\d{4}$/;
      expect(formatTimestampToDate(1698678887603)).toMatch(dateFormatRegex);
    });
  });
});
