/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { getLatestRueckfrageActivityDate } from "./getLatestRueckfrageActivityDate";
import { RueckfrageHeader } from "../../api/types";

describe("get latest topic activity date tests", () => {
  test("without lastAnsweredDate on topic header", () => {
    const rueckfrageHeader: RueckfrageHeader = {
      id: "1",
      title: "test topic",
      nachrichtHeader: {
        id: "1",
        vorgangId: "1",
        sendAt: 123,
        title: "test topic",
        postfachId: "sjkdfhlksdfsdf",
        nachrichtEventId: "1",
        accessible: true,
        trustLevel: "LOW"
      },
      accessible: true,
      trustLevel: "LOW",
      status: "NEW",
      links: []
    };

    expect(getLatestRueckfrageActivityDate(rueckfrageHeader)).toBe(123);
  });
  test("with lastAnsweredDate on topic header", () => {
    const rueckfrageHeader: RueckfrageHeader = {
      id: "1",
      title: "test topic",
      nachrichtHeader: {
        id: "1",
        vorgangId: "1",
        sendAt: 123,
        title: "test topic",
        postfachId: "sjkdfhlksdfsdf",
        nachrichtEventId: "1",
        accessible: true,
        trustLevel: "LOW",
        answeredAt: 456
      },
      accessible: true,
      trustLevel: "LOW",
      status: "ANSWERED",
      links: []
    };

    expect(getLatestRueckfrageActivityDate(rueckfrageHeader)).toBe(456);
  });
});
