/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { RueckfrageHeader } from "../../api/types";
import { getRueckfrageLink } from "./getRueckfrageLink";

describe("get rueckfrage link tests", () => {
  test("without links", () => {
    const rueckfrageHeader: RueckfrageHeader = {
      id: "1",
      title: "test topic",
      nachrichtHeader: {
        id: "1",
        vorgangId: "1",
        sendAt: 123,
        title: "test topic",
        postfachId: "sjkdfhlksdfsdf",
        nachrichtEventId: "1",
        accessible: false,
        trustLevel: "LOW"
      },
      accessible: false,
      trustLevel: "LOW",
      links: [],
      status: "NEW"
    };

    expect(getRueckfrageLink(rueckfrageHeader)).toBeUndefined();
  });
  test("without rueckfrage link", () => {
    const rueckfrageHeader: RueckfrageHeader = {
      id: "1",
      title: "test topic",
      nachrichtHeader: {
        id: "1",
        vorgangId: "1",
        sendAt: 123,
        title: "test topic",
        postfachId: "sjkdfhlksdfsdf",
        nachrichtEventId: "1",
        accessible: false,
        trustLevel: "LOW"
      },
      accessible: false,
      trustLevel: "LOW",
      links: [{ rel: "test", href: "http://test:123/test" }],
      status: "NEW"
    };

    expect(getRueckfrageLink(rueckfrageHeader)).toBeUndefined();
  });
  test("with rueckfrage link", () => {
    const rueckfrageHeader: RueckfrageHeader = {
      id: "1",
      title: "test topic",
      nachrichtHeader: {
        id: "1",
        vorgangId: "1",
        sendAt: 123,
        title: "test topic",
        postfachId: "sjkdfhlksdfsdf",
        nachrichtEventId: "1",
        accessible: true,
        trustLevel: "LOW"
      },
      accessible: true,
      trustLevel: "LOW",
      status: "NEW",
      links: [
        { rel: "test", href: "http://test:123/test" },
        { rel: "rueckfrage", href: "http://test:123/topic" }
      ]
    };

    expect(getRueckfrageLink(rueckfrageHeader)).toBe("http://test:123/topic");
  });
});
