/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Rueckfrage, RueckfrageHeader } from "../../api/types";
import { isRueckfrageHeaderMarkedNew, isRueckfrageMarkedNew } from "./isRueckfrageMarkedNew";

describe("is rueckfrage marked new tests", () => {
  describe("rueckfrage tests", () => {
    test("without userMessages in rueckfrage", () => {
      const rueckfrage: Rueckfrage = {
        id: "1",
        title: "test topic",
        nachricht: {
          id: "1",
          vorgangId: "1",
          sendAt: 123,
          title: "test topic",
          postfachId: "sjkdfhlksdfsdf",
          nachrichtEventId: "1",
          message: "test message",
          attachments: [],
          accessible: true,
          trustLevel: "LOW"
        },
        antworten: [],
        accessible: true,
        trustLevel: "LOW"
      };

      expect(isRueckfrageMarkedNew(rueckfrage)).toBeTruthy();
    });
    test("with userMessages in topic", () => {
      const rueckfrage: Rueckfrage = {
        id: "1",
        title: "test topic",
        nachricht: {
          id: "1",
          vorgangId: "1",
          sendAt: 123,
          title: "test topic",
          postfachId: "sjkdfhlksdfsdf",
          nachrichtEventId: "1",
          message: "test message",
          attachments: [],
          accessible: true,
          trustLevel: "LOW"
        },
        antworten: [
          {
            id: "2",
            rueckfrageId: "1",
            postfachId: "sjkdfhlksdfsdf",
            nachrichtEventId: "1",
            message: "test message",
            attachments: []
          }
        ],
        accessible: true,
        trustLevel: "LOW"
      };

      expect(isRueckfrageMarkedNew(rueckfrage)).toBeFalsy();
    });
  });

  describe("rueckfrage header tests", () => {
    test("without answeredAt in rueckfrage header", () => {
      const rueckfrageHeader: RueckfrageHeader = {
        id: "1",
        title: "test topic",
        nachrichtHeader: {
          id: "1",
          vorgangId: "1",
          sendAt: 123,
          title: "test topic",
          postfachId: "sjkdfhlksdfsdf",
          nachrichtEventId: "1",
          accessible: true,
          trustLevel: "LOW"
        },
        accessible: true,
        trustLevel: "LOW",
        links: [],
        status: "NEW"
      };

      expect(isRueckfrageHeaderMarkedNew(rueckfrageHeader)).toBeTruthy();
    });
    test("with answeredAt in rueckfrage header", () => {
      const rueckfrageHeader: RueckfrageHeader = {
        id: "1",
        title: "test topic",
        nachrichtHeader: {
          id: "1",
          vorgangId: "1",
          sendAt: 123,
          title: "test topic",
          postfachId: "sjkdfhlksdfsdf",
          accessible: true,
          trustLevel: "LOW",
          nachrichtEventId: "1"
        },
        accessible: true,
        trustLevel: "LOW",
        links: [],
        status: "ANSWERED"
      };

      expect(isRueckfrageHeaderMarkedNew(rueckfrageHeader)).toBeFalsy();
    });
  });
});
