/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { RueckfrageHeader } from "../../api/types";
import { sortRueckfrageHeaders } from "./sortRueckfrageHeaders";

describe("Sort rueckfrage headers tests", () => {
  const rueckfrageHeader1: RueckfrageHeader = {
    id: "1",
    title: "test topic 1",
    nachrichtHeader: {
      id: "1",
      vorgangId: "1",
      sendAt: 1,
      title: "test topic 1",
      postfachId: "asdassadf",
      nachrichtEventId: "1",
      accessible: true,
      trustLevel: "LOW"
    },
    accessible: true,
    trustLevel: "LOW",
    status: "NEW",
    links: []
  };
  const rueckfrageHeader2: RueckfrageHeader = {
    id: "2",
    title: "test topic 2",
    nachrichtHeader: {
      id: "2",
      vorgangId: "2",
      sendAt: 2,
      title: "test topic 2",
      postfachId: "asdassadf",
      nachrichtEventId: "1",
      accessible: true,
      trustLevel: "LOW"
    },
    accessible: true,
    trustLevel: "LOW",
    status: "NEW",
    links: []
  };

  function getSortedIds(topicHeaders: RueckfrageHeader[]) {
    return topicHeaders.sort(sortRueckfrageHeaders).map((t) => t.id);
  }

  test("both unread => latest first", () => {
    expect(getSortedIds([rueckfrageHeader1, rueckfrageHeader2])).toEqual(["2", "1"]);
  });
  test("both read => latest reply first", () => {
    expect(
      getSortedIds([
        {
          ...rueckfrageHeader2,
          status: "ANSWERED",
          nachrichtHeader: { ...rueckfrageHeader1.nachrichtHeader, answeredAt: 123 }
        },
        {
          ...rueckfrageHeader1,
          status: "ANSWERED",
          nachrichtHeader: { ...rueckfrageHeader2.nachrichtHeader, answeredAt: 456 }
        }
      ])
    ).toEqual(["1", "2"]);
  });
  test("unread first", () => {
    expect(
      getSortedIds([
        {
          ...rueckfrageHeader2,
          status: "ANSWERED",
          nachrichtHeader: { ...rueckfrageHeader2.nachrichtHeader, answeredAt: 123 }
        },
        rueckfrageHeader1
      ])
    ).toEqual(["1", "2"]);
    expect(
      getSortedIds([
        {
          ...rueckfrageHeader1,
          status: "ANSWERED",
          nachrichtHeader: { ...rueckfrageHeader1.nachrichtHeader, answeredAt: 456 }
        },
        rueckfrageHeader2
      ])
    ).toEqual(["2", "1"]);
  });
  test("with multiple topic headers (complex test)", () => {
    const topicHeaders: RueckfrageHeader[] = [
      {
        ...rueckfrageHeader1,
        id: "1",
        status: "NEW",
        nachrichtHeader: { ...rueckfrageHeader1.nachrichtHeader, sendAt: 8 }
      },
      {
        ...rueckfrageHeader1,
        id: "2",
        status: "NEW",
        nachrichtHeader: { ...rueckfrageHeader1.nachrichtHeader, sendAt: 3 }
      },
      {
        ...rueckfrageHeader1,
        id: "3",
        status: "ANSWERED",
        nachrichtHeader: { ...rueckfrageHeader1.nachrichtHeader, answeredAt: 789 }
      },
      {
        ...rueckfrageHeader1,
        id: "4",
        status: "ANSWERED",
        nachrichtHeader: { ...rueckfrageHeader1.nachrichtHeader, answeredAt: 123 }
      },
      {
        ...rueckfrageHeader1,
        id: "5",
        status: "ANSWERED",
        nachrichtHeader: { ...rueckfrageHeader1.nachrichtHeader, answeredAt: 912 }
      },
      {
        ...rueckfrageHeader1,
        id: "6",
        status: "ANSWERED",
        nachrichtHeader: { ...rueckfrageHeader1.nachrichtHeader, answeredAt: 456 }
      }
    ];

    expect(getSortedIds(topicHeaders)).toEqual(["1", "2", "5", "3", "6", "4"]);
  });
});
