/*
 * Copyright (c) 2023-2024.  Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten
 * des Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

import React from "react";
import { Outlet, RouteObject } from "react-router-dom";
import { App } from "../App";
import { OverviewPage } from "./overview/OverviewPage";
import { DetailPage } from "./detail/DetailPage";
import { VersionInfo } from "./version-info/version-info";
import { ErrorPage } from "../components/Core/Error Page/ErrorPage";
import { useTranslateFunction } from "../hooks/useTranslate";
import { PrivacyPolicy } from "./static/PrivacyPolicy";
import { Imprint } from "./static/Imprint";

export function getRouterConfig() {
  const isProduction = process.env.NODE_ENV === "production";

  const childRoutes: RouteObject[] = [
    {
      index: true,
      element: <OverviewPage />
    },
    {
      path: "/detail/:encodedRueckfrageLink",
      element: <DetailPage />
    },
    {
      path: "/privacy-policy",
      element: <PrivacyPolicy />
    },
    {
      path: "/imprint",
      element: <Imprint />
    }
  ];

  if (!isProduction) {
    childRoutes.push(
      {
        path: "/info",
        element: <VersionInfo />
      },
      {
        path: "/generic-error",
        element: <GenericError />
      }
    );
  }

  const routerConfig: RouteObject[] = [
    {
      path: "/",
      element: <App mainContent={<Outlet />} />,
      children: childRoutes,
      errorElement: <ErrorBoundary />
    }
  ];

  return routerConfig;
}

/**
 * Component to display errors
 * see https://reactrouter.com/en/main/route/error-element
 */
function ErrorBoundary() {
  const translate = useTranslateFunction();
  return (
    <App
      mainContent={
        <ErrorPage
          errorType="notFound"
          headline={translate("common.error.notFound.heading")}
          message={translate("common.error.notFound.message")}
          goBackTo={translate("common.error.goBackTo")}
          linkText={translate("common.error.linkText")}
          errorIconAltText={translate("common.error.errorIconAltText")}
          notFoundIconAltText={translate("common.error.notFoundIconAltText")}
        />
      }
    />
  );
}

function GenericError() {
  const translate = useTranslateFunction();
  return (
    <ErrorPage
      errorType="generic"
      message={translate("common.error.generic.message")}
      goBackTo={translate("common.error.goBackTo")}
      linkText={translate("common.error.linkText")}
      errorIconAltText={translate("common.error.errorIconAltText")}
      notFoundIconAltText={translate("common.error.notFoundIconAltText")}
    />
  );
}
