/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

import React from "react";
import { Heading } from "../../components/Data Display/Heading/Heading";
import { Text } from "../../components/Data Display/Text/Text";
import { useTranslateFunction } from "../../hooks/useTranslate";

export function Imprint() {
  const translate = useTranslateFunction();
  document.title = translate("common.imprint") + " | " + translate("common.htmlTitle");
  return (
    <>
      <Heading headingLevel={1}>Impressum</Heading>
      <Heading headingLevel={2}>Herausgeber</Heading>
      <Text variant="info">
        <b>Bayerisches Staatsministerium für Digitales</b>
        <br />
        Oskar-von-Miller-Ring 35
        <br />
        80333 München
        <br />
        Telefon: 089/453549-0
        <br />
        Telefax: 089/453549-242
        <br />
        E-Mail: <a href="mailto:Info@stmd.bayern.de">Info@stmd.bayern.de</a>
        <br />
        Vertretungsberechtigter: Ministerialdirektor Dr. Hans Michael Strepp
        <br />
        USt-Identifikationsnummer (gemäß § 27 a Umsatzsteuergesetz): DE811335517
      </Text>
      <Heading headingLevel={2}>Laufender Technischer Betrieb/Technische Betreuung</Heading>
      <Text variant="info">
        <b>Bayerisches Landesamt für Steuern</b>
        <br />
        Rechenzentrum Nord
        <br />
        Voigtländerstr. 7/9
        <br />
        90489 Nürnberg
        <br />
        E-Mail: <a href="mailto:Kundenbetreuung@rz-nord.bayern.de">Kundenbetreuung@rz-nord.bayern.de</a>
        <br />
        Web:{" "}
        <a href="https://www.finanzamt.bayern.de/LfSt/Rechenzentrum_Nord/">
          https://www.finanzamt.bayern.de/LfSt/Rechenzentrum_Nord/
        </a>
      </Text>
      <Heading headingLevel={2}>Nutzungsbedingungen</Heading>
      <Text variant="info">
        Texte, Bilder, Grafiken sowie die Gestaltung dieser Internetseiten unterliegen dem Urheberrecht. Nicht
        urheberrechtlich geschützt sind nach § 5 des Urheberrechtsgesetz (UrhG)
      </Text>
      <Text variant="info">
        <ul>
          <li>
            Gesetze, Verordnungen, amtliche Erlasse und Bekanntmachungen sowie Entscheidungen und amtlich verfasste
            Leitsätze zu Entscheidungen und
          </li>
          <li>
            andere amtliche Werke, die im amtlichen Interesse zur allgemeinen Kenntnisnahme veröffentlicht worden sind,
            mit der Einschränkung, dass die Bestimmungen über Änderungsverbot und Quellenangabe in § 62 Abs. 1 bis 3 und
            § 63 Abs. 1 und 2 UrhG entsprechend anzuwenden sind.
          </li>
        </ul>
      </Text>
      <Text variant="info">
        Sie dürfen von Ihnen nur zum privaten und sonstigen eigenen Gebrauch im Rahmen des § 53 Urheberrechtsgesetz
        (UrhG) verwendet werden. Eine Vervielfältigung oder Verwendung dieser Seiten oder Teilen davon in anderen
        elektronischen oder gedruckten Publikationen und deren Veröffentlichung ist nur mit unserer Einwilligung
        gestattet. Diese erteilen Ihnen auf Anfrage, die für den Inhalt Verantwortlichen.
      </Text>
      <Text variant="info">
        Weiterhin können Texte, Bilder, Grafiken und sonstige Dateien ganz oder teilweise dem Urheberrecht Dritter
        unterliegen. Auch über das Bestehen möglicher Rechte Dritter geben Ihnen, die für den Inhalt Verantwortlichen
        nähere Auskünfte.
      </Text>
      <Text variant="info">
        Der Nachdruck und die Auswertung von Pressemitteilungen und Reden sind mit Quellenangabe allgemein gestattet.
      </Text>
      <Heading headingLevel={2}>Bildnachweis</Heading>
      <Text variant="info">
        Die Bildrechte für die auf dieser Webseite verwendeten Bilder sind geklärt. Quellenangaben erfolgen in der
        Bildunterschrift oder im Alternativtext zum Bild. Bilder ohne explizite Quellenangaben sind grundsätzlich mit
        Quelle „Bayerisches Staatsministerium für Digitales” zu führen. Ihre Nutzung bedarf der Zustimmung des
        Bayerischen Staatsministerium für Digitales. Sollten Sie sich, trotz aller Sorgfalt unserer Arbeit, in einem
        Bildrecht verletzt fühlen, wenden Sie sich bitte an{" "}
        <a href="mailto:oeffentlichkeitsarbeit@stmd.bayern.de">oeffentlichkeitsarbeit@stmd.bayern.de</a>
      </Text>
      <Heading headingLevel={2}>Haftungsausschluss</Heading>
      <Text variant="info">
        Alle auf dieser Internetseite bereitgestellten Informationen haben wir nach bestem Wissen und Gewissen
        erarbeitet und geprüft. Eine Gewähr für die jederzeitige Aktualität, Richtigkeit, Vollständigkeit und
        Verfügbarkeit der bereit gestellten Informationen können wir allerdings nicht übernehmen. Ein Vertragsverhältnis
        mit den Nutzern des Internetangebots kommt nicht zustande.
      </Text>
      <Text variant="info">
        Wir haften nicht für Schäden, die durch die Nutzung dieses Internetangebots entstehen. Dieser Haftungsausschluss
        gilt nicht, soweit die Vorschriften des § 839 BGB (Haftung bei Amtspflichtverletzung) einschlägig sind. Für
        etwaige Schäden, die beim Aufrufen oder Herunterladen von Daten durch Schadsoftware oder der Installation oder
        Nutzung von Software verursacht werden, übernehmen wir keine Haftung.
      </Text>
      <Heading headingLevel={2}>Links</Heading>
      <Text variant="info">
        Von unseren eigenen Inhalten sind Querverweise („Links“) auf die Webseiten anderer Anbieter zu unterscheiden.
        Durch diese Links ermöglichen wir lediglich den Zugang zur Nutzung fremder Inhalte nach § 8 Telemediengesetz.
        Bei der erstmaligen Verknüpfung mit diesen Internetangeboten haben wir diese fremden Inhalte daraufhin
        überprüft, ob durch sie eine mögliche zivilrechtliche oder strafrechtliche Verantwortlichkeit ausgelöst wird.
        Wir können diese fremden Inhalte aber nicht ständig auf Veränderungen überprüfen und daher auch keine
        Verantwortung dafür übernehmen. Für illegale, fehlerhafte oder unvollständige Inhalte und insbesondere für
        Schäden, die aus der Nutzung oder Nichtnutzung von Informationen Dritter entstehen, haftet allein der jeweilige
        Anbieter der Seite.
      </Text>
      <Heading headingLevel={2}>Gender-Hinweis</Heading>
      <Text variant="info">
        Wir bemühen uns darum, auf dieser Webseite männliche und weibliche Personenbezeichnungen zu verwenden. Im Falle
        von reinen Funktionsbezeichnungen greifen wir auf die männliche Form zurück (Generisches Maskulinum). Hierbei
        schließt die Verwendung der männlichen Form alle Geschlechter mit ein.
      </Text>
    </>
  );
}
