/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

import React from "react";
import { Heading } from "../../components/Data Display/Heading/Heading";
import { Text } from "../../components/Data Display/Text/Text";
import { useTranslateFunction } from "../../hooks/useTranslate";

export function PrivacyPolicy() {
  const translate = useTranslateFunction();
  document.title = translate("common.privacyPolicy") + " | " + translate("common.htmlTitle");
  return (
    <>
      <Heading headingLevel={1}>Datenschutz</Heading>
      <Heading headingLevel={2}>Datenschutzerklärung</Heading>
      <Text variant="info">
        Diese Datenschutzerklärung bezieht sich auf die Verarbeitung personenbezogener Daten im Rahmen dieses
        Internetauftritts, einschließlich der dort angebotenen Dienste.
      </Text>
      <Text variant="info">
        Für nähere Informationen zur Verarbeitung Ihrer personenbezogenen Daten können Sie uns unter den unter
        „Ansprechpartner“ genannten Kontaktdaten erreichen.
      </Text>
      <Heading headingLevel={2}>Allgemeine Hinweise</Heading>
      <Heading headingLevel={3}>Name und Kontaktdaten des Verantwortlichen</Heading>
      <Text variant="info">
        Bayerisches Staatsministerium für Digitales <br />
        Oskar-von-Miller-Ring 35 <br />
        80333 München <br />
        E-Mail: <a href="mailto:Info@stmd.bayern.de">Info@stmd.bayern.de</a>
      </Text>
      <Heading headingLevel={3}>Kontaktdaten des Datenschutzbeauftragten</Heading>
      <Text variant="info">Sie erreichen unseren Datenschutzbeauftragten unter:</Text>
      <Text variant="info">
        Behördlicher Datenschutzbeauftragter des Bayerischen Staatsministeriums für Digitales
        <br />
        Oskar-von-Miller-Ring 35
        <br />
        80333 München
        <br />
        E-Mail: <a href="mailto:datenschutzbeauftragter@stmd.bayern.de">datenschutzbeauftragter@stmd.bayern.de</a>
      </Text>
      <Heading headingLevel={3}>Zwecke und Rechtsgrundlagen für die Verarbeitung personenbezogener Daten</Heading>
      <Text variant="info">
        Zweck der Verarbeitung ist die Erfüllung der uns vom Gesetzgeber zugewiesenen öffentlichen Aufgaben,
        insbesondere die Information der Öffentlichkeit.
      </Text>
      <Text variant="info">
        Die Rechtsgrundlage für die Verarbeitung Ihrer Daten ergibt sich, soweit nichts anderes angegeben ist, aus Art.
        4 Abs. 1 des Bayerischen Datenschutzgesetzes (BayDSG) in Verbindung mit Art. 6 Abs. 1 Buchstabe e der
        Datenschutzgrundverordnung (DSGVO). Demnach ist es uns erlaubt, die zur Erfüllung einer uns obliegenden Aufgabe
        erforderlichen Daten zu verarbeiten.
      </Text>
      <Text variant="info">
        Soweit Sie in eine Verarbeitung eingewilligt haben, stützt sich die Datenverarbeitung auf Art. 6 Abs. 1
        Buchstabe a DSGVO.
      </Text>
      <Heading headingLevel={3}>Empfänger von personenbezogenen Daten</Heading>
      <Text variant="info">Der technische Betrieb unserer Datenverarbeitungssysteme erfolgt durch:</Text>
      <Text variant="info">
        Landesamt für Digitalisierung, Breitband und Vermessung
        <br />
        IT-Dienstleistungszentrum des Freistaats Bayern (IT-DLZ)
        <br />
        St.-Martin-Straße 47, 81541 München
        <br />
        E-Mail: <a href="mailto:webmaster@bayern.de">webmaster@bayern.de</a>
      </Text>
      <Text variant="info">
        Gegebenenfalls werden Ihre Daten an die zuständigen Aufsichts- und Rechnungsprüfungsbehörden zur Wahrnehmung der
        jeweiligen Kontrollrechte übermittelt.
      </Text>
      <Text variant="info">
        Zur Abwehr von Gefahren für die Sicherheit in der Informationstechnik können bei elektronischer Übermittlung
        Daten an das Landesamt für Sicherheit in der Informationstechnik weitergeleitet werden und dort auf Grundlage
        von Art. 12 ff. des Bayerischen E-Government-Gesetzes verarbeitet werden.
      </Text>
      <Heading headingLevel={3}>Dauer der Speicherung der personenbezogenen Daten</Heading>
      <Text variant="info">
        Ihre Daten werden nur so lange gespeichert, wie dies für die Erreichung des jeweiligen Speicherzwecks
        erforderlich ist oder dies durch gesetzliche Aufbewahrungsfristen vorgeschrieben ist.
      </Text>
      <Heading headingLevel={3}>Rechte der betroffenen Person</Heading>
      <Text variant="info">
        Soweit wir von Ihnen personenbezogene Daten verarbeiten, stehen Ihnen als Betroffener nachfolgende Rechte zu:
      </Text>
      <Text variant="info">
        <ul>
          <li>
            Werden Ihre personenbezogenen Daten verarbeitet, so haben Sie das Recht, Auskunft über die zu Ihrer Person
            gespeicherten Daten zu erhalten (Art. 15 DSGVO).
          </li>
          <li>
            Sollten unrichtige personenbezogene Daten verarbeitet werden, steht Ihnen ein Recht auf Berichtigung zu.
            Unter Berücksichtigung der Zwecke der Verarbeitung haben Sie ebenfalls das Recht, die Vervollständigung
            unvollständiger personenbezogener Daten – auch mittels einer ergänzenden Erklärung – zu verlangen (Art. 16
            DSGVO).
          </li>
          <li>
            Liegen die gesetzlichen Voraussetzungen vor, so können Sie die Löschung oder Einschränkung der Verarbeitung
            verlangen, sowie Widerspruch gegen die Verarbeitung einlegen (Art. 17, 18 und 21 DSGVO).
          </li>
          <li>
            Wenn Sie in die Verarbeitung eingewilligt haben oder ein Vertrag zur Datenverarbeitung besteht und die
            Datenverarbeitung mithilfe automatisierter Verfahren durchgeführt wird, steht Ihnen gegebenenfalls ein Recht
            auf Datenübertragbarkeit zu (Art. 20 DSGVO).
          </li>
          <li>
            Falls Sie in die Verarbeitung eingewilligt haben und die Verarbeitung auf dieser Einwilligung beruht, können
            Sie die Einwilligung jederzeit für die Zukunft widerrufen. Die Rechtmäßigkeit der aufgrund der Einwilligung
            bis zum Widerruf erfolgten Datenverarbeitung wird durch diesen nicht berührt.
          </li>
        </ul>
      </Text>
      <Text variant="info">
        Ausführlichere Informationen zu diesen Rechten erteilt Ihnen auch unser behördlicher Datenschutzbeauftragter.
      </Text>
      <Heading headingLevel={3}>Beschwerderecht bei der Aufsichtsbehörde</Heading>
      <Text variant="info">
        Weiterhin besteht ein Beschwerderecht beim Bayerischen Landesbeauftragten für den Datenschutz. Diesen können Sie
        unter folgenden Kontaktdaten erreichen:
      </Text>
      <Text variant="info">
        Postanschrift: Postfach 22 12 19, 80502 München
        <br />
        Adresse: Wagmüllerstraße 18, 80538 München
        <br />
        Telefon: 089 / 212672-0
        <br />
        Telefax: 089 / 212672-50
        <br />
        E-Mail: <a href="mailto:poststelle@datenschutz-bayern.de">poststelle@datenschutz-bayern.de</a>
        <br />
        Internet: <a href="https://www.datenschutz-bayern.de">www.datenschutz-bayern.de</a>
      </Text>
      <Heading headingLevel={2}>Hinweise zum Internetangebot</Heading>
      <Heading headingLevel={3}>Technische Umsetzung</Heading>
      <Text variant="info">
        Unser Web-Server wird durch das Bayerische Landesamt für Digitalisierung, Breitband und Vermessung betrieben.
        Die von Ihnen im Rahmen des Besuchs unseres Webauftritts übermittelten personenbezogenen Daten werden daher in
        unserem Auftrag durch das Bayerische Landesamt für Digitalisierung, Breitband und Vermessung verarbeitet:
      </Text>
      <Text variant="info">
        Landesamt für Digitalisierung, Breitband und Vermessung
        <br />
        IT-Dienstleistungszentrum des Freistaats Bayern (IT-DLZ)
        <br />
        St.-Martin-Straße 47, 81541 München
        <br />
        E-Mail: <a href="mailto:webmaster@bayern.de">webmaster@bayern.de</a>
      </Text>
      <Heading headingLevel={3}>Protokollierung</Heading>
      <Text variant="info">
        Wenn Sie diese oder andere Internetseiten aufrufen, übermitteln Sie über Ihren Internetbrowser Daten an unseren
        Webserver. Die folgenden Daten werden während einer laufenden Verbindung zur Kommunikation zwischen Ihrem
        Internetbrowser und unserem Webserver aufgezeichnet:
      </Text>
      <Text variant="info">
        <ul>
          <li>Datum und Uhrzeit der Anforderung</li>
          <li>Name der angeforderten Datei</li>
          <li>Seite, von der aus die Datei angefordert wurde</li>
          <li>Zugriffsstatus (beispielsweise Datei übertragen, Datei nicht gefunden)</li>
          <li>verwendete Webbrowser und verwendetes Betriebssystem</li>
          <li>vollständige IP-Adresse des anfordernden Rechners</li>
          <li>übertragene Datenmenge</li>
        </ul>
      </Text>
      <Text variant="info">
        Aus Gründen der technischen Sicherheit, insbesondere zur Abwehr von Angriffsversuchen auf unseren Webserver,
        werden diese Daten von uns gespeichert. Nach spätestens sieben Tagen werden die Daten durch Verkürzung der
        IP-Adresse auf Domain-Ebene anonymisiert, so dass es nicht mehr möglich ist, einen Bezug auf einzelne Nutzer
        herzustellen.
      </Text>
      <Text variant="info">
        Zur Abwehr von Gefahren für die Sicherheit in der Informationstechnik werden die Daten an das Landesamt für
        Sicherheit in der Informationstechnik weitergeleitet und dort auf Grundlage der Art. 12 ff. des Bayerischen
        E-Government-Gesetzes verarbeitet.
      </Text>
      <Heading headingLevel={3}>Aktive Komponenten</Heading>
      <Text variant="info">
        Wir verwenden aktive Komponenten wie Javascript, Java-Applets oder Active-X-Controls. Diese Funktion kann durch
        die Einstellung Ihres Internetbrowsers von Ihnen abgeschaltet werden.
      </Text>
      <Heading headingLevel={3}>Cookies</Heading>
      <Text variant="info">
        Beim Zugriff auf dieses Internetangebot werden von uns Cookies (kleine Dateien) auf Ihrer Festplatte mit einer
        Gültigkeitsdauer von 12 Monaten gespeichert. Wir verwenden diese ausschließlich dazu, Sie bei diesem und
        weiteren Besuchen unserer Webseite zu identifizieren. Die meisten Browser sind so eingestellt, dass sie die
        Verwendung von Cookies akzeptieren, diese Funktion kann aber durch die Einstellung des Internetbrowsers von
        Ihnen für die laufende Sitzung oder dauerhaft abgeschaltet werden.
      </Text>
      <Heading headingLevel={2}>Informationen zu weiteren Datenverarbeitungen</Heading>
      <Heading headingLevel={3}>Elektronische Post (E-Mail)</Heading>
      <Text variant="info">
        Informationen, die unverschlüsselt per Elektronische Post (E-Mail) an das Bayerische Staatsministerium für
        Digitales gesendet werden, können möglicherweise auf dem Übertragungsweg von Dritten gelesen werden. Wir können
        in der Regel auch die Identität nicht überprüfen und wissen nicht, wer sich hinter einer E-Mail-Adresse
        verbirgt. Eine rechtssichere Kommunikation durch einfache E-Mail ist daher nicht gewährleistet. Wir setzen – wie
        viele E-Mail-Anbieter – Filter gegen unerwünschte Werbung (SPAM-Filter) ein, die in seltenen Fällen auch normale
        E-Mails fälschlicherweise automatisch als unerwünschte Werbung einordnen und löschen können. E-Mails, die
        schädigende Programme (Viren) enthalten, werden in jedem Fall automatisch gelöscht.
      </Text>
      <Text variant="info">
        Wenn Sie schutzwürdige Nachrichten an das Bayerische Staatsministerium für Digitales senden wollen, empfehlen
        wir Ihnen, diese zu verschlüsseln und zu signieren, um eine unbefugte Kenntnisnahme und Verfälschung auf dem
        Übertragungsweg zu verhindern oder die Nachricht auf konventionellem Postwege zu senden.
      </Text>
      <Text variant="info">
        Mit S/MIME verschlüsselte E-Mails können Sie schicken an:{" "}
        <a href="mailto:Info@stmd.bayern.de">Info@stmd.bayern.de</a>
      </Text>
      <Text variant="info">
        <a href="https://www.ebca.de/nutzung-der-ebca/zertifikate-finden/">
          Den öffentlichen Schlüssel der Poststelle können Sie bei TeleTrusT EBCA herunterladen
        </a>{" "}
        bzw. finden diesen hier:{" "}
        <a href="https://www.stmd.bayern.de/wp-content/uploads/2019/02/Poststelle_StMD.zip">
          Download des Schlüssels (ZIP-Datei, 1,4KB)
        </a>{" "}
        .
      </Text>
      <Text variant="info">
        Bitte teilen Sie auch mit, ob und auf welche Weise wir Ihnen zur Beantwortung Ihrer Zusendungen verschlüsselte
        E-Mails übersenden können und ob Sie – falls dies nicht möglich ist – mit einer unverschlüsselten Antwort per
        E-Mail auf Ihr Schreiben einverstanden sind. Wenn Sie über keine Möglichkeit zum Empfang verschlüsselter E-Mails
        verfügen, bitten wir zur Beantwortung Ihrer schutzwürdigen Nachrichten Ihre Postanschrift zu nennen.
      </Text>
      <Heading headingLevel={3}>
        Veranstaltungen des Bayerischen Staatsministerium für Digitales, Presse- und Öffentlichkeitsarbeit
      </Heading>
      <Text variant="info">
        Das Bayerische Staatsministerium für Digitales tritt auch als Organisator oder Mitorganisator diverser
        Veranstaltungen auf.
      </Text>
      <Text variant="info">
        Im Falle einer Einladung zu oder Teilnahme an einer Veranstaltung verarbeitet das Bayerische Staatsministerium
        für Digitales personenbezogene Daten (Name, Adresse etc.). Dies kann über verschiedene Kommunikationswege
        erfolgen, zum Beispiel durch Ausfüllen eines Formulars, eines Webformulars, per E-Mail, per Telefon.
      </Text>
      <Text variant="info">
        Welche personenbezogenen Daten dabei an das Bayerische Staatsministerium für Digitales übermittelt werden,
        ergibt sich aus dem jeweiligen Formular, der jeweiligen Eingabemaske beziehungsweise den in einem etwaigen
        Gespräch abgefragten Daten.
      </Text>
      <Text variant="info">
        <ul>
          <li>
            <i>Datenerhebung von Begleitpersonen</i>
            <br />
            Für die ordnungsgemäße Abwicklung der Veranstaltung werden dabei auch Daten von Begleitpersonen der
            eingeladenen Teilnehmer erhoben und verarbeitet. Diesen stehen ebenso wie allen anderen von Datenerhebungen
            Betroffenen die oben genannten Rechte zu, insbesondere auf Auskunft über Art und Umfang der gespeicherten
            Daten, Widerspruch gegen die Verarbeitung und Löschung der Daten. Insofern wird auf die Ausführungen zu den
            Rechten der betroffenen Personen verwiesen.
          </li>
          <li>
            <i>Datenerhebung aus öffentlich zugänglichen Quellen</i>
            <br />
            Das Bayerische Staatsministerium für Digitales erhebt und verarbeitet darüber hinaus zu diesem Zweck auch
            Daten, die aus öffentlich zugänglichen Quellen stammen, zum Beispiel von Homepages der betroffenen Personen
            oder aus öffentlich zugänglichen Verzeichnissen.
          </li>
          <li>
            <i>Weiteres Verfahren bei diesen Datenerhebungen</i>
            <br />
            Die personenbezogenen Daten werden nicht unbefugt an Dritte übermittelt, sondern für die interne Verwendung
            beim Bayerischen Staatsministerium für Digitales und für den Zweck der Organisation und Abwicklung von
            Veranstaltungen (etwa Erstellung von Gästelisten, Ermöglichung von Zugangskontrollen etc.) gespeichert und
            verarbeitet. Das Bayerische Staatsministerium für Digitales kann die Weitergabe an einen oder mehrere
            Auftragsverarbeiter veranlassen, der die personenbezogenen Daten im Auftrag des Bayerischen
            Staatsministerium für Digitales nur für eine interne Verwendung, die dem Bayerischen Staatsministerium für
            Digitales zuzurechnen ist, nutzt. <br /> Je nach Art der Veranstaltung tritt das Bayerische
            Staatsministerium für Digitales neben einem weiteren Kooperationspartner als Mitveranstalter auf. In diesen
            Fällen werden die zu Veranstaltungszwecken erhobenen Daten an unsere Kooperationspartner übermittelt, wobei
            diese die Daten ebenfalls ausschließlich zu diesem Zweck der ordnungsgemäßen Abwicklung der Veranstaltung
            verwenden dürfen. Welche Kooperationspartner dies im Einzelfall sind, wird gesondert im Rahmen der
            Organisation der Veranstaltung jeweils mitgeteilt.
          </li>
        </ul>
      </Text>
      <Text variant="info">
        Die Daten werden nur so lange gespeichert, wie dies für die Organisation und Abwicklung der Veranstaltungen
        sowie für unsere Aufgabenwahrnehmung im Bereich der Öffentlichkeitsarbeit erforderlich ist.
      </Text>
      <Text variant="info">
        Als Empfänger von Anschreiben/Einladungen können Sie jederzeit der Zusendung weiterer Anschreiben/Einladungen
        widersprechen.
      </Text>
      <Heading headingLevel={3}>Fotoaufnahmen</Heading>
      <Text variant="info">
        Im Rahmen unserer Presse- und Öffentlichkeitsarbeit werden bei Veranstaltungen und Terminen Fotos und Videos
        aufgenommen, auf denen Sie gegebenenfalls erkennbar zu sehen sind. Der Aufnahme und/oder einer Veröffentlichung
        können Sie widersprechen.
        <br /> Bitte nutzten Sie für Ihren Widerspruch die oben genannten Kontaktdaten.
      </Text>
      <Heading headingLevel={3}>Bewerbungen beim Bayerischen Staatsministerium für Digitales</Heading>
      <Text variant="info">
        Das Bayerische Staatsministerium für Digitales erhebt und verarbeitet die personenbezogenen Daten von Bewerbern
        zum Zwecke der Abwicklung des Bewerbungsverfahrens. Die Verarbeitung kann auch auf elektronischem Wege erfolgen.
        Dies ist insbesondere dann der Fall, wenn ein Bewerber entsprechende Bewerbungsunterlagen auf dem elektronischen
        Wege, beispielsweise per E-Mail, übermittelt. Kommt es zu einem Beschäftigungsverhältnis mit einem Bewerber,
        werden die übermittelten Daten zum Zwecke der Abwicklung des Beschäftigungsverhältnisses unter Beachtung der
        gesetzlichen Vorschriften gespeichert. Zudem können Daten im Einstellungsverfahren an Behörden, die für die
        Abwicklung des Beschäftigungsverhältnisses zuständig sind (z.B. Landesamt für Finanzen), übermittelt werden.
        Kommt es zu keinem Beschäftigungsverhältnis, so werden die Bewerbungsunterlagen nach Bekanntgabe der
        Absageentscheidung nach den einschlägigen Vorschriften gelöscht, sofern einer Löschung keine sonstigen
        berechtigten Interessen des Bayerischen Staatsministerium für Digitales entgegenstehen. Sonstiges berechtigtes
        Interesse in diesem Sinne ist beispielsweise eine Beweispflicht in einem Verfahren nach dem Allgemeinen
        Gleichbehandlungsgesetz (AGG).
      </Text>
    </>
  );
}
