/*
 * Copyright (c) 2023. Das Land Schleswig-Holstein vertreten durch den Ministerpräasidenten des
 * Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

import React, { useEffect, useState } from "react";
import axios from "axios";
import { LoadingPage } from "../../components/Core/Loading Page/LoadingPage";
import { useTranslateFunction } from "../../hooks/useTranslate";
import { Text } from "../../components/Data Display/Text/Text";

interface VersionInfoData {
  name?: string;
  version?: string;
  buildTime?: string;
  javaVersion: string;
  isProduction: boolean;
}

interface VersionInfoResponse {
  data: VersionInfoData;
}

export function VersionInfo() {
  const [versionInfoData, setVersionInfoData] = useState<VersionInfoData | undefined>();
  const translate = useTranslateFunction();

  useEffect(() => {
    fetchVersionInfoData();
  }, []);

  const fetchVersionInfoData = async () => {
    if (process.env.ANTRAGSRAUM_HOST) {
      const versionInfoResponse: VersionInfoResponse = await axios.get(process.env.ANTRAGSRAUM_HOST);
      setVersionInfoData(versionInfoResponse.data);
    }
  };

  if (!versionInfoData) {
    return <LoadingPage loadingMessage={translate("common.loadingMessage")} />;
  }

  return (
    <>
      {versionInfoData.name && versionInfoData.version && (
        <Text variant="info">
          {versionInfoData.name}: {versionInfoData.version}
        </Text>
      )}
      <Text variant="info">
        {process.env.PROJECT_NAME}: {process.env.PROJECT_VERSION}
      </Text>
    </>
  );
}
