/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
const path = require("path");
const fs = require("fs");
const webpack = require("webpack");
require("dotenv").config();
const HtmlWebpackPlugin = require("html-webpack-plugin");
const CopyPlugin = require("copy-webpack-plugin");

const prod = process.env.NODE_ENV === "production";
const envWhitelist = ["NODE_ENV", "PROJECT_NAME", "PROJECT_VERSION", "ANTRAGSRAUM_HOST", "INFO_MANAGER_HOST"];

// Parse package.json to project object, which contains the project name
const packageJsonFilePath = "./package.json";
if (fs.existsSync(packageJsonFilePath)) {
  const jsonContent = fs.readFileSync(packageJsonFilePath, "utf8");
  const project = JSON.parse(jsonContent);
  process.env.PROJECT_NAME = project.name;
  process.env.PROJECT_VERSION = project.version;
}

module.exports = {
  entry: "./src/index.tsx",
  output: {
    path: path.resolve(__dirname, "docker", "dist"),
    filename: "index.js",
    publicPath: "/"
  },
  mode: prod ? "production" : "development",
  devtool: prod ? "source-map" : "eval-source-map",
  module: {
    rules: [
      {
        test: /\.tsx?$/,
        exclude: /node_modules/,
        resolve: {
          extensions: [".ts", ".tsx", ".js", ".json"]
        },
        use: "ts-loader"
      },
      {
        test: /\.css$/i,
        use: ["style-loader", "css-loader"]
      },
      {
        test: /\.(png|jp(e*)g|svg|gif|ttf|json)$/,
        type: "asset/resource"
      }
    ]
  },
  devServer: {
    historyApiFallback: true,
    compress: true,
    port: 8082,
    proxy: {
      "/auth": {
        target: process.env.ANTRAGSRAUM_HOST,
        changeOrigin: true
      },
      "/login": {
        target: process.env.ANTRAGSRAUM_HOST,
        changeOrigin: true
      },
      "/api": {
        target: process.env.ANTRAGSRAUM_HOST,
        changeOrigin: true
      }
    }
  },
  plugins: [
    new HtmlWebpackPlugin({
      template: "./public/index.html"
    }),
    new CopyPlugin({
      patterns: [
        {
          from: path.join(__dirname, "public"),
          context: path.join(__dirname, "public"),
          globOptions: {
            ignore: ["**/index.html"]
          },
          to: path.join(__dirname, "docker", "dist")
        }
      ]
    }),
    // only expose the whitelisted properties
    new webpack.DefinePlugin({
      "process.env": JSON.stringify(
        envWhitelist.reduce((newEnv, property) => {
          if (process.env[property]) {
            newEnv[property] = process.env[property];
          }
          return newEnv;
        }, {})
      )
    })
  ]
};
